<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:eps="http://www.eumetsat.de/eps">

<xsl:template match="documentation">
    <xsl:apply-templates/>
</xsl:template>


<xsl:template match="sourceDetails">
<html>
    <head>
        <title><xsl:value-of select="./ownerFormat/name"/> - <xsl:value-of select="./ownerFormat/version"/> - <xsl:value-of select="./name"/></title>
    </head>
    <body>
        <font size="2">Generation time : <xsl:value-of select="../@generationTime"/></font><br/>
        <font size="2">Document type : <xsl:value-of select="../@documentType"/></font><br/>
        <font size="2">Related format : <a href="{./ownerFormat/details}"> <xsl:value-of select="./ownerFormat/name"/> - <xsl:value-of select="./ownerFormat/version"/> </a></font><br/>
         <hr size="1" width="100%"/>
       
        <h1><xsl:value-of select="./ownerFormat/name"/> - <xsl:value-of select="./ownerFormat/version"/> - <xsl:value-of select="./name"/></h1>
        <h2>General information</h2>
        <ul>
            <li>Source name : <xsl:value-of select="./name"/></li>
            <li>Description : <xsl:value-of select="./description"/></li>
            <li>Type : <xsl:value-of select="./type"/></li>
            <li>Total size (bytes) : <xsl:value-of select="./totalSize"/></li>
        </ul>
        <xsl:apply-templates select="content"/>        
    </body>
</html>
</xsl:template>

<xsl:template match="content">
        <h2>Source content description</h2>
        <center>
        <table width="90%">
            <tr>
               <td valign="middle"><b><font size="3">Name</font></b></td>
                <td valign="middle" align="center"><b><font size="3">Units</font></b></td>
                <td valign="middle"><b><font size="3">Type</font></b></td>
                <td valign="middle" align="center"><b><font size="3">Length<br/>(bytes:bits)</font></b></td>
            </tr>
           <xsl:apply-templates/>
        </table>
        </center>
</xsl:template>

<xsl:template match="variable">
    <font size="2"><xsl:value-of select="./@name"/> = <xsl:value-of select="./@value"/></font><br/>
</xsl:template>


<xsl:template match="*[var]">
    <xsl:apply-templates/>
</xsl:template>

<xsl:template match="*[targ]">
    <xsl:apply-templates/>
</xsl:template>

<xsl:template match="var">
        <xsl:value-of select="."/>
</xsl:template>

<xsl:template match="targ">
 ?<xsl:value-of select="."/>?
</xsl:template>


<xsl:template match="element">

        <tr>
            <td valign="middle">
                <img src="icons/16x16/empty.png" height="10" width="{./depth * 5}"/>
                <xsl:if test="count (./children/*) > 0">
                    <img src="icons/16x16/folder_open.png" hspace="5"/>
                </xsl:if>
                <xsl:if test="count (./children/*) = 0">
                    <img src="icons/16x16/leaf.png" hspace="5"/>
                </xsl:if>
                <font size="3"><xsl:value-of select="./name"/></font>
                <xsl:if test="(./description != '-') or (count (variables/*) > 0)">
                    <br/>
                    <img align="left" src="icons/16x16/empty.png" height="10" width="{./depth * 5 + 10}"/>
                    <table><tr><td>
                    <font color="#888888" size="2"><xsl:value-of select="./description"/></font><br/>
                    <xsl:apply-templates select="variables/variable"/>                    
                    </td></tr></table>
                 </xsl:if>
            </td>
            <td valign="middle">
                    <font size="3"><xsl:value-of select="./unit"/></font>
            </td>            
            <td valign="middle">
                <xsl:if test="string-length(./typeDetails/text ()) > 0">
                    <a href="{./typeDetails}">
                        <xsl:if test="contains (./type, '(')">
                            <font size="3"><xsl:value-of select="substring-before (./type, '(')"/></font>
                         </xsl:if>
                        <xsl:if test="contains (./type, '(') = false">
                            <font size="3"><xsl:value-of select="./type"/></font>
                         </xsl:if>
                     </a>
                       <xsl:if test="contains (./type, '(')">
                            <font size="3">(<xsl:value-of select="substring-after (./type, '(')"/></font>
                         </xsl:if>
                </xsl:if>
                <xsl:if test="string-length(typeDetails/text ()) = 0">
                    <font size="3"><xsl:apply-templates select="./type"/></font>
                </xsl:if>
            </td>
            <td valign="middle" align="right" nowrap="true">
                <font size="3"><xsl:apply-templates select="./totalSize"/></font>
            </td>
        </tr>
        <xsl:apply-templates select="./children/element"/>
</xsl:template>


<xsl:template match="source">
        <li>
        <h3><xsl:value-of select="./@name"/></h3>
        <ul>
            <li>Description : <xsl:value-of select="./description"/></li>
            <li>Type : <xsl:value-of select="./type"/></li>
            <li>Total size (bytes) : <xsl:value-of select="./size"/></li>
        </ul>
        
        </li>
</xsl:template>


<!--

<xsl:template match="tr[@class = 'tte-row-1']">
    <tr>
        <xsl:for-each select="td">
            <td>        
                <xsl:value-of select="./text ()"/>
            </td>
         </xsl:for-each>
    </tr>
</xsl:template>


<xsl:template match="*|/">
   <xsl:element name="{name (.)}">
      <xsl:apply-templates/>
  </xsl:element>
</xsl:template>

<xsl:template match="text()|@*">
  <xsl:value-of select="."/>
</xsl:template>
-->



</xsl:stylesheet>
